import es, cmdlib, popuplib, gamethread

info = es.AddonInfo()
info['name']        = "Guns Menu"
info['version']     = "1.0.0"
info['author']      = "DanielB" 
info['url']         = "http://forums.eventscripts.com/viewtopic.php?t=34141" 
info['description'] = "Basic Guns Menu for DanielBs Advanced Deathmatch" 

dm = es.import_addon('dm')

class GunsManager:
    def __init__(self):
        self.cache = {} # {userid: {'saved':bool, 'last': [prim, sec]}}
        main = popuplib.easymenu('dm_guns_main', None, self.mainSelect)
        main.settitle('Guns Menu')
        main.addoption('new', 'New Guns')
        main.addoption('same', 'Same Guns')
        main.addoption('save', 'Always Same Guns')
        
        prim = popuplib.easymenu('dm_guns_prim', None, self.primSelect)
        prim.settitle('Select Primary Weapon')
        #primary = ['m249', 'tmp', 'p90', 'ump45', 'mac10', 'mp5navy', 'm3', 'xm1014', 'galil', 'sg552', 'm4a1', 'aug', 'ak47', 'g3sg1', 'scout', 'sg550', 'awp']
        #for weapon in primary:
        #    prim.addoption(weapon, weapon)
        for i in ['Rifles', 'SMGs', 'Shotguns', 'Machine Guns']:
            prim.addoption(i, i)
            
        rifles = popuplib.easymenu('dm_guns_rifles', None, self.gunSelect)
        for i in ['galil', 'sg552', 'm4a1', 'aug', 'ak47', 'g3sg1', 'scout', 'sg550', 'awp']:
            rifles.addoption(i, i)
        
        smg = popuplib.easymenu('dm_guns_smg', None, self.gunSelect)
        for i in ['tmp', 'p90', 'ump45', 'mac10', 'mp5navy']:
            smg.addoption(i, i)
            
        shotty = popuplib.easymenu('dm_guns_shotty', None, self.gunSelect)
        for i in ['m3', 'xm1014']:
            shotty.addoption(i, i)
            
        mgun = popuplib.easymenu('dm_guns_mgun', None, self.gunSelect)
        mgun.addoption('m249', 'm249')
            
        for i in [rifles, smg, shotty, mgun]:
            i.addoption('prim', 'Change weapon class')
            
        
        sec = popuplib.easymenu('dm_guns_sec', None, self.secSelect)
        sec.settitle('Select Secondary Weapon')
        pistols = ['glock', 'usp', 'p228', 'deagle', 'fiveseven', 'elite']
        for weapon in pistols:
            sec.addoption(weapon, weapon)
            
    def gunSelect(self, userid, choice, popupname):
        if choice == 'prim':
            popuplib.find('dm_guns_main').send(userid)
        else:
            userid = int(userid)
            if not userid in self.cache:
                self.add(userid)
            
            self.cache[userid]['last'] = [choice]
            popuplib.find('dm_guns_sec').send(userid)
            
    def unload(self):
        for i in ['dm_guns_main', 'dm_guns_prim', 'dm_guns_sec', 'dm_guns_mgun', 'dm_guns_shotty', 'dm_guns_smg', 'dm_guns_rifles']:
            popuplib.delete(i)
        
    def add(self, userid):
        self.cache[int(userid)] = {'saved': False, 'last': []}
        
    def remove(self, userid):
        userid = int(userid)
        if userid in self.cache:
            del self.cache[userid]
            
    def player_spawn(self, userid):
        userid = int(userid)
        if userid in self.cache:
            if self.cache[userid]['saved']:
                self.supply(userid)
            else:
                popuplib.close('dm_guns_main', userid)
                popuplib.find('dm_guns_main').send(userid)
                
    def supply(self, userid):
        es.server.queuecmd('es_xfire %s player_weaponstrip kill'%userid)
        es.server.queuecmd('es_xgive %s player_weaponstrip'%userid)
        es.server.queuecmd('es_xfire %s player_weaponstrip strip'%userid)
        gamethread.delayed(0.1, self.give, userid)
            
    def give(self, userid):
        for weapon in self.cache[userid]['last']:
            es.server.queuecmd('es_xgive %s weapon_%s'%(userid, weapon))
        es.server.queuecmd('es_xgive %s weapon_knife'%userid)
                
    def mainSelect(self, userid, choice, popupname):
        userid = int(userid)
        if choice == 'save':
            if self.cache[userid]['last']:
                self.supply(userid)
                self.cache[userid]['saved'] = True
            else:
                tell(userid, 'You have not selected weapons!')
                popuplib.find('dm_guns_main').send(userid)
        
        elif choice == 'same':
            if self.cache[userid]['last']:
                self.supply(userid)
            else:
                tell(userid, 'You have not selected weapons!')
                popuplib.find('dm_guns_main').send(userid)
                
        else:
            popuplib.find('dm_guns_prim').send(userid)
            
    def primSelect(self, userid, choice, popupname):
        #['Rifles', 'SMGs', 'Shotguns', 'Machine Guns']
        if choice == 'Rifles':
            popuplib.find('dm_guns_rifles').send(userid)
        if choice == 'SMGs':
            popuplib.find('dm_guns_smg').send(userid)
        if choice == 'Shotguns':
            popuplib.find('dm_guns_shotty').send(userid)
        if choice == 'Machine Guns':
            popuplib.find('dm_guns_mgun').send(userid)
        
    def secSelect(self, userid, choice, popupname):
        userid = int(userid)
        self.cache[userid]['last'].append(choice)
        
        self.supply(userid)

gunsManager = GunsManager()




def load():
    for userid in es.getUseridList():
        gunsManager.add(userid)
        
    cmdlib.registerSayCommand('guns', cmd_guns, 'Open the guns menu')
    
    dm.msg('Loaded Addon - Guns Menu')
    
def unload():
    gunsManager.unload()
    cmdlib.unregisterSayCommand('guns')
    dm.msg('Unloaded Addon - Guns menu')
    
def cmd_guns(userid, args):
    if settings.gunmenu:
        popuplib.close('dm_guns_main', userid)
        popuplib.find('dm_guns_main').send(userid)
    else:
        tell(userid, 'The guns menu has been disabled')
        
        
def player_spawn(event_var):
    gunsManager.player_spawn(event_var['userid'])
    
def player_activate(event_var):
    gunsManager.add(event_var['userid'])
    
def player_disconnect(event_var):
    gunsManager.remove(event_var['userid'])